#!/usr/bin/perl

use DBI;
use Net::Ping;
use Time::HiRes;
use POSIX qw(strftime);
use Errno qw(ENOENT);
require "/etc/mrlg.cfg";

sub db_connect($) {
  my $verbose = shift;
                                                                                                           
  return $global_dbh if (defined $global_dbh);
                                                                                                           
  my $dsn = "DBI:$database_type:database=$database_name:host=$database_host:port=$database_port";
  print "DBI Connecting to $dsn\n" if $verbose;
                                                                                                           
  # Note: We do all manual error checking for db errors
  my $dbh = DBI->connect($dsn, $database_user, $database_pass,
                         { PrintError => 0, RaiseError => $verbose });
                                                                                                           
  $global_dbh = $dbh;
  return $global_dbh;
}
                                                                                                           
sub db_disconnect {
  $global_dbh->disconnect() if (defined $global_dbh);
  $global_dbh = undef;
  return 0;
}

sub do_ping() {
  

	foreach my $host (@pinghosts) {
	 
	    $p = Net::Ping->new();
	    $p->hires();
	    ($ret, $duration, $ip) = $p->ping($host, 5.5);
	    my $latency = sprintf("%.2f", $duration * 1000 );
	    $hosts{$host} = $latency;
	}
	foreach my $thishost ( keys %hosts ) {
	    $sth = $dbh->prepare("INSERT INTO latency (time,host,latency) VALUES (NOW(),?,?)") or goto DB_FAILURE;
	    $sth->execute($thishost, $hosts{$thishost}) or goto DB_FAILURE;
	    $sth->finish;
	
	    $p->close();
	}
	return;
	
	DB_FAILURE:
		# Had a DB error.  Handle as configured.
  		print "ERROR: Database Call Failed!\n  $DBI::errstr\n";
  		return ("Failure");
 
}

sub daemonize {
    $0 = "mrlg.pl: Pinging...";
   # open STDOUT, ">>$log" or die "Can't write to $log: $!";
    defined(my $pid = fork)   or die "Can't fork: $!";
    exit if $pid;
    setsid                    or die "Can't start a new session: $!";
    umask 0;
}

&daemonize;

our $dbh = db_connect(0) or goto DB_FAILURE;
while (true) {
	&do_ping;
	sleep 5;
}
db_disconnect;
