#!/usr/bin/perl

use Errno qw(ENOENT);
use DBI;
require '/etc/mrlg.cfg';

use strict;

my $verbose = 1;

my $optimize_active_table = 1;

my $global_dbh;

sub db_connect($) {
  my $verbose = shift;

  return $global_dbh if (defined $global_dbh);

  my $dsn = "DBI:$database_type:database=$database_name:host=$database_host:port=$database_port";
  print "DBI Connecting to $dsn\n" if $verbose;

  # Note: We do all manual error checking for db errors
  my $dbh = DBI->connect($dsn, $database_user, $database_pass, 
                         { PrintError => 0, RaiseError => $verbose });

  $global_dbh = $dbh;
  return $global_dbh;
}

sub db_disconnect {
  $global_dbh->disconnect() if (defined $global_dbh);
  $global_dbh = undef;
  return 0;
}


BEGIN:
{
  # connect to the database 
  my $dbh = db_connect(1);
  die "$DBI::errstr\n" unless($dbh);

  $dbh->do("LOCK TABLES latency WRITE, latreport WRITE");
  # copy ALL rows to the reporting table, replacing any existing rows
  my $rows = $dbh->do("REPLACE INTO latreport SELECT * FROM latency");
  print "$rows copied/updated to reporting table\n";

  # delete any rows that expired more than an hour ago
  my $rows = $dbh->do("DELETE FROM latency WHERE time < NOW() - INTERVAL 48 HOUR");
  print "$rows expired rows deleted from active table\n";
 
  $dbh->do("UNLOCK TABLES");
  # delete anything older than 90 days.
  my $rows = $dbh->do("DELETE FROM latreport WHERE time < NOW() - INTERVAL 2160 HOUR");
  print "$rows expired rows (>90 days) deleted from reporting table\n";
  

  # optimize the active table
  $dbh->do("OPTIMIZE TABLE latency");
  $dbh->do("OPTIMIZE TABLE latreport");
  print "Optimized active table.\n";

}


